@@ -608,6 +608,8 @@ def main():
 
             if hasattr(exchange, 'skip') and exchange.skip:
                 dump(green(exchange.id), 'skipped')
+            elif hasattr(exchange, 'alias') and exchange.alias:
+                dump(green(exchange.id), 'Skipped alias')
             else:
                 if symbol:
                     load_exchange(exchange)
